@@ -1,5 +1,6 @@
-;; SKK tutorial (version 3.6 for SKK version 6.19 and later versions.)
-;; Copyright (C) 1988, 1992 Masahiko Sato (masahiko@sato.riec.tohoku.ac.jp)
+;; SKK tutorial (version 3.8 for SKK version 8.6 and later versions.)
+;; Copyright (C) 1988, 1989, 1990, 1991, 1992, 1993, 1994, 1995
+;; Masahiko Sato (masahiko@sato.riec.tohoku.ac.jp)
 
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -15,6 +16,17 @@
 ;; along with SKK, see the file COPYING.  If not, write to the Free
 ;; Software Foundation Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
+;; Following people contributed modifications to skk-tut.el:
+;;	Wataru Matsui (matsui@gf.hm.rd.sanyo.co.jp)
+;;	Shuhei KOBAYASHI (tba4kac@aix370.ecip.tohoku.ac.jp)
+;;	ͦ (jshen@cas.org)
+;;	Haru'yasu Ueda (hal@sics.se)
+;;	Toyonobu Yoshida (toyono-y@is.aist-nara.ac.jp)
+;;	IIDA Yosiaki (iida@sayla.secom-sis.co.jp)
+;;	紴 (PBC01764@niftyserve.or.jp / minakaji@mix.or.jp)
+
+;; version 3.8 released 1995.5.13
+;; version 3.7 released 1993.5.20
 ;; version 3.6 released 1992.9.19
 ;; version 3.5 released 1992.5.31
 ;; version 3.4 released 1992.4.12
@@ -46,10 +58,8 @@ installed SKK if necessary.")
     (setq v (skk-version))
     (if (< (string-to-int (char-to-string (aref v 0))) 6)
 	;; the version of skk just loaded is an old one
-	(progn
-	  (setq features skk-features-save)
-	  (error
-	   "Your skk%s is too old to run the tutorial.  It must be at least version 6." v)))
+	(error
+	   "Your skk%s is too old to run the tutorial.  It must be at least version 6." v))
     (setq skk-problem-count 0
 	  skk-tutorial-end nil
 	  skk-jisyo-save nil)
@@ -68,17 +78,22 @@ installed SKK if necessary.")
     (setq skk-japanese-tut (looking-at ";; SKK Japanese"))
     ;; if the editor is Mule, modify the text a little
     (if (boundp 'MULE)
-	(save-excursion
-	  (while (search-forward "Nemacs" nil t)
-	    (delete-region (match-beginning 0) (match-end 0))
-	    (insert "Mule"))
-	  (while (search-forward "Σ" nil t)
-	    (delete-region (match-beginning 0) (match-end 0))
-	    (insert "ͣ"))))
+	;; modified by Shuhei KOBAYASHI, 1994.6.29.
+	;; 95.4.9 Mikio Nakajima
+	(progn
+	  (save-excursion (replace-string "Nemacs" "Mule" nil))
+	  (save-excursion
+	    (replace-string "Σ" "ͣ" nil) )))
     (switch-to-buffer (get-buffer-create "**"))
     (erase-buffer)
     (setq skk-tutorial-map (make-keymap))
-    (fillarray skk-tutorial-map 'skk-error)
+    ;; modified by ͦ, 1994.9.8.
+    ;; modified by Haru'yasu Ueda, 1994.9.21.
+    ;; modified by Toyonobu Yoshida, 1994.10.3.
+    ;; modified by IIDA Yosiaki, 1994.10.6.
+    (fillarray (if (arrayp skk-tutorial-map)
+		   skk-tutorial-map
+		 (car (cdr skk-tutorial-map))) 'skk-error)
     (use-local-map skk-tutorial-map)
     (erase-buffer)
     (skk-get-new-page)
@@ -87,6 +102,8 @@ installed SKK if necessary.")
     (other-window 1)
     (enlarge-window (- (window-height (selected-window)) 20))
     (switch-to-buffer (get-buffer-create "**"))
+    ;; modified by Shuhei KOBAYASHI, 1994.6.29.
+    (make-local-variable 'skk-search-prog-list)
     (setq skk-search-prog-list '((j-search-jisyo-file skk-tut-jisyo 0 t)))
     (local-set-key "\C-xn" 'skk-next-window)
     (local-set-key "\C-xq" 'skk-quit-tutorial)
@@ -138,7 +155,8 @@ installed SKK if necessary.")
   (save-excursion
     (set-buffer " *skk-tutorial*")
     (goto-char (point-min))
-    (search-forward "--\n")
+    ;; modified by Toyonobu Yoshida, 1994.10.3.
+    (search-forward "--\n" nil t)
     (delete-region (point-min) (point))
     (if (looking-at ";")
 	(let (p)
