@@ -1,5 +1,5 @@
 /* skkserv.c
- * SKK Server Version 3.9.2 of Jun 7, 1994
+ * SKK Server Version 3.9.3 of Jun 17, 1994
  * Copyright (C) 1994 Yukiyoshi Kameyama (kam@riec.tohoku.ac.jp)
  *
  * Programmed by
@@ -13,6 +13,7 @@
  * Koji Kawaguchi (guchi@pfu.fujitsu.co.jp) for various improvement
  * Hironobu Takahashi (takahasi@tiny.or.jp) for patch for char/int typing
  * Kazushi Marukawa (kazushi@kubota.co.jp) for cleaning up behavior in PRIVATE mode
+ * TSUMURA Kazumasa (tsumura@fml.ec.tmit.ac.jp) for pointing out a bug in okuri-ari/nasi test
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -106,7 +107,7 @@
  *	Global Variables
  */
 
-char	pgmver[] = "3.9.2 ";	/* version number */
+char	pgmver[] = "3.9.3 ";	/* version number */
 
 char	*pgmnm;		/* program name */
 char	*jname;		/* name of shared dictionary */
@@ -611,8 +612,13 @@ int	commsock;
     if ((*pbuf & 0x80) != 0) {
       while (*pbuf != ' ')
 	pbuf ++;
+#ifdef oldbug
       if ((*(pbuf-1) & 0x80) == 0)
 	sstyle = 1;
+#else
+      if ((*(pbuf-1) >= 'a') && (*(pbuf-1) <= 'z'))
+	sstyle = 1;
+#endif
     }
   }
 
